/*-------------------------------------------------------------------
 *
 *  @file server.h
 *
 *  @author Collin R. Mulliner <collin@mulliner.org>
 *
 *  (c) Collin R. Mulliner
 *
 *  This is part of the Bluetooth Location Tracker (BLT) project.
 *
 *-------------------------------------------------------------------*/

/*
 * This file is part of blt_server
 *
 * blt_server is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * blt_server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blt_server; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#ifndef __SERVER_H__
#define __SERVER_H__

/* tracker slots are compile time static */
#define MAX_NUM_TRACKERS	50
/* data slots are compile time static */
#define MAX_NUM_DATAS		200

struct blt_server_session_t {
	
	char *tracker_ip;	/**< ip to listen on for tracker connections */
	int tracker_port;	/**< port to listen on */
	
	char *data_ip;		/**< ip to listen on for data connections */
	int data_port;		/**< port to listen on */

	struct blt_tracker_config_t defaultCfg;	/**< default tracker config. */

	/* location tracker clients */
	struct blt_tracker_client_session_t *trackers;
	int numTrackers;
	pthread_mutex_t trackers_sem;
		
	/* location data clients */
	struct blt_data_client_session_t *datas;
	int numDatas;
	pthread_mutex_t datas_sem;

	struct blt_dev_names_t devNames;	/**< all known device names */
	
	struct blt_pusher_t pushServer;	/**< the main push server */
	
	struct blt_loc_names_t locationNames; /**< all known locations */
	
	SSL_CTX *ssl_ctx;
};
#endif

void *trackers_wait_for_clients(void *args);
void trackers_init(struct blt_server_session_t *server);
void *datas_wait_for_clients(void *args);
void datas_init(struct blt_server_session_t *server);
