/*-------------------------------------------------------------------
 *
 *  @file util.h
 *
 *  @author Collin R. Mulliner <collin@mulliner.org>
 *
 *  (c) Collin R. Mulliner
 *
 *  This is part of the Bluetooth Location Tracker (BLT) project.
 *
 *-------------------------------------------------------------------*/

/*
 * This file is part of blt_server
 *
 * blt_server is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * blt_server is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with blt_server; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#ifndef __UTIL_H__
#define __UTIL_H__

#include <openssl/ssl.h>

/**
 *  @brief readbuf descriptor
 */
struct readbuf_t {
	SSL *ssl;
	unsigned char *buffer;	/**< buffer */
	unsigned int size;		/**< buffer size */
	unsigned int leng;		/**< input length */
};

#endif

void scanWithEsc(char *in, char *out, int outleng);
void printWithEsc(char *in, char *out, int outleng);
void strcpyendchr(char *in, char *out, char delimiter, int outleng);
void parsemac(char *in, char *out);
ssize_t nwrite(int fd, const void *vptr, size_t n);
int fd_canread(int fd, int wait);

/* readbuf lib */
void readbufDestroy(struct readbuf_t *buf);
void readbufInit(struct readbuf_t *buf, int size, SSL *ssl);
int readbuf(struct readbuf_t *buf, int fd, char *out, int maxout, int wait);
int readbufGetLine(struct readbuf_t *buf, char *out, int maxout);
